# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.03.23
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.applications_api import ApplicationsApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestApplicationsApi(unittest.TestCase):
    """ApplicationsApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.applications_api.ApplicationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_application(self):
        """Test case for delete_application

        Remove an application  # noqa: E501
        """
        pass

    def test_env_config_delete(self):
        """Test case for env_config_delete

        Remove an environment configuration  # noqa: E501
        """
        pass

    def test_env_config_get(self):
        """Test case for env_config_get

        Get environment configuration  # noqa: E501
        """
        pass

    def test_env_config_get_all(self):
        """Test case for env_config_get_all

        Get all environment configuration  # noqa: E501
        """
        pass

    def test_env_config_post(self):
        """Test case for env_config_post

        Add an environment configuration row  # noqa: E501
        """
        pass

    def test_env_config_put(self):
        """Test case for env_config_put

        Update environment configuration  # noqa: E501
        """
        pass

    def test_get_application(self):
        """Test case for get_application

        Get a application  # noqa: E501
        """
        pass

    def test_get_applications(self):
        """Test case for get_applications

        Get applications  # noqa: E501
        """
        pass

    def test_get_environment(self):
        """Test case for get_environment

        Get an environment  # noqa: E501
        """
        pass

    def test_post_application(self):
        """Test case for post_application

        Create an application  # noqa: E501
        """
        pass

    def test_put_application(self):
        """Test case for put_application

        Create or update an application  # noqa: E501
        """
        pass

    def test_put_environment(self):
        """Test case for put_environment

        Update an environment  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
